@@ -3,7 +3,7 @@
   y <- matInd[1]
   if (length(dimsizes) > 1) {
     for (i in 2:length(dimsizes)) {
-      y <- y + (matInd[i] - 1) * prod(dimsizes[1:(i - 1)])
+      y <- y + (matInd[i] - 1) * prod(dimsizes[seq_len(i - 1)])
     }
   }
   return(y)
@@ -14,8 +14,8 @@
   y <- matrix(0, nrow = length(dimsizes), ncol = 1)
   if (NROW(y) > 1) {
     for (i in seq(from = length(dimsizes), to = 2)) {
-      y[i] <- ceiling(linInd / prod(dimsizes[1:(i - 1)]))
-      linInd <- linInd - (y[i] - 1) * prod(dimsizes[1:(i - 1)])
+      y[i] <- ceiling(linInd / prod(dimsizes[seq_len(i - 1)]))
+      linInd <- linInd - (y[i] - 1) * prod(dimsizes[seq_len(i - 1)])
     }
   }
   y[1] <- linInd
